@@ -31,7 +31,9 @@ _column_doc = param_doc(
 _running_doc = param_doc(
     name='running',
     desc='''
-    Aggregation will be calculated as sliding window.
+    See :ref:`Aggregation buckets guide <buckets_guide>` to see examples of how this parameter works.
+
+    Specifies if the aggregation will be calculated as a sliding window.
     ``running`` and ``bucket_interval`` parameters determines when new buckets are created.
 
     * ``running`` = True
@@ -45,10 +47,10 @@ _running_doc = param_doc(
 
       * ``bucket_interval`` = 0
 
-        Left boundary of window will be bound to start time. For each tick aggregation will be calculated in
-        [start_time; tick_t].
+        Left boundary of window will be set to query start time. For each tick aggregation will be calculated in
+        the interval [start_time; tick_t] from query start time to the tick's timestamp (inclusive).
 
-    * ``running`` = False
+    * ``running`` = False (default)
 
       buckets partition the [query start time, query end time) interval into non-overlapping intervals
       of size ``bucket_interval`` (with the last interval possibly of a smaller size).
@@ -68,6 +70,8 @@ _running_doc = param_doc(
 _all_fields_doc = param_doc(
     name='all_fields',
     desc="""
+    See :ref:`Aggregation buckets guide <buckets_guide>` to see examples of how this parameter works.
+
     * ``all_fields`` = True
 
       output ticks include all fields from the input ticks
@@ -95,15 +99,25 @@ _all_fields_doc = param_doc(
 _all_fields_with_policy_doc = param_doc(
     name='all_fields',
     desc="""
+    See :ref:`Aggregation buckets guide <buckets_guide>` to see examples of how this parameter works.
+
     - If ``all_fields`` False - output tick will have only aggregation fields.
 
+    - If ``all_fields`` is True and ``running`` is False - additional fields will be copied from the first
+      tick in the bucket to the output tick.
+
     - If ``all_fields`` False and ``running`` True - output ticks are created when a tick enters or leaves the
       sliding window.
 
-    - If ``all_fields`` True - an output tick is generated only for arrival events,
+    - If ``all_fields`` True and ``running`` True - an output tick is generated only for arrival events,
       but all attributes from the input tick causing an arrival event are copied over to the output tick
       and the aggregation is added as another attribute.
 
+    - If ``all_fields`` True and ``running`` "when_ticks_exit_window" -
+      an output tick is generated only for exit events,
+      but all attributes from the exiting tick are copied over to the output tick
+      and the aggregation is added as another attribute.
+
     - If ``all_fields`` set to "first", "last", "high", or "low" - explicitly set tick selection policy for all
       fields values. For "high" and "low" "PRICE" field will be selected as an input.
       Otherwise, you will get the runtime error.
@@ -114,7 +128,8 @@ _all_fields_with_policy_doc = param_doc(
       first parameter.
     """,
     default=False,
-    annotation=Union[Literal[True, False, "first", "last", "high", "low"], HighTick, LowTick]
+    str_annotation=("True, False, 'when_ticks_exit_window', 'first', 'last', 'high', 'low', "
+                    ":py:func:`~onetick.py.agg.high_tick`, :py:func:`~onetick.py.agg.low_tick`"),
 )
 _bucket_interval_doc = param_doc(
     name='bucket_interval',
@@ -887,7 +902,7 @@ def copy_method(obj, mimic=True, drop_examples=False):
     return _decorator
 
 
-def copy_signature(obj, add_self=False, drop_parameters=[], return_annotation='Source'):
+def copy_signature(obj, add_self=False, drop_parameters=None, return_annotation='Source'):
     """
     Decorator that copies signature of the callable ``obj`` to the decorated function.
     """
