@@ -227,7 +227,7 @@ class Distinct(_AggregationTSSelection):
                  keys: Union[str, List[str], _Column, List[_Column]],
                  key_attrs_only: bool = True,
                  *args, **kwargs):
-        keys = keys if type(keys) is list else [keys]   # type: ignore
+        keys = keys if isinstance(keys, list) else [keys]   # type: ignore
         super().__init__(column=keys, *args, **kwargs)  # type: ignore
         self.key_attrs_only = key_attrs_only
 
