@@ -383,7 +383,7 @@ class _TickSequence(_StateBase):
         return isinstance(self._owner, _EmulateInputObject)
 
     def _default_schema(self):
-        return {field: type for field, type in self._owner.schema.items()}
+        return dict(self._owner.schema.items())
 
     @property
     def schema(self) -> dict:
@@ -391,7 +391,7 @@ class _TickSequence(_StateBase):
         Get schema of the tick sequence.
         """
         fields = None
-        if type(self._schema) is list:
+        if isinstance(self._schema, list):
             fields = self._schema
             self._schema = None
         if not self._schema:
