@@ -127,11 +127,12 @@ def table(self: 'Source', inplace=False, strict: bool = True, **schema) -> Optio
 
 
 def __add_field_parse_value(value):
-    if type(value) is tuple:
+    if isinstance(value, tuple):
         value, dtype = value
     else:
         dtype = ott.get_object_type(value)
 
+        # pylint: disable-next=unidiomatic-typecheck
         if type(value) is str and len(value) > ott.string.DEFAULT_LENGTH:
             dtype = ott.string[len(value)]
 
@@ -213,6 +214,7 @@ def _replace_positive_lag_operator_with_tmp_column(value):
                 )
             name = f"__{name}_{operation.index}_NEW__"
             return _Column(name, column.dtype, column.obj_ref, precision=getattr(column, "_precision", None))
+        return None
 
     op, replace_tuples = value._replace_parameters(fun, return_replace_tuples=True)
     return op, {str(new): old for old, new in replace_tuples}
@@ -228,7 +230,7 @@ def _update_field(self: 'Source', field, value):
     if names_mapping:
         self.add_fields(names_mapping, inplace=True)
 
-    if type(value) is tuple:
+    if isinstance(value, tuple):
         # support to be compatible with adding fields to get rid of some strange problems
         # but really we do not use passed type, because update field does not support it
         value, _ = value
@@ -327,9 +329,7 @@ def _validate_before_setting(key, value):
         value = value.item()
     if not (
         ott.is_type_supported(ott.get_object_type(value))
-        or isinstance(value, _Operation)
-        or type(value) is tuple
-        or isinstance(value, _ColumnAggregation)
+        or isinstance(value, (_Operation, tuple, _ColumnAggregation))
     ):
         raise TypeError(f'It is not allowed to set objects of "{type(value)}" type')
     return value
