@@ -161,16 +161,16 @@ def where_clause(
         condition = condition._make_python_way_bool_expression()
     if isinstance(condition, _QueryEvalWrapper):
         condition = condition.to_eval_string(self._tmp_otq)
-    where = self.copy(
+    where_branch = self.copy(
         ep=otq.WhereClause(
             where=str(condition), discard_on_match=discard_on_match, stop_on_first_mismatch=stop_on_first_mismatch
         )
     )
 
-    if_source = where.copy()
+    if_source = where_branch.copy()
     if_source.node().out_pin("IF")
 
-    else_source = where.copy()
+    else_source = where_branch.copy()
     else_source.node().out_pin("ELSE")
     # TODO: add ability to remove then this ep, because it is required only for right output
     else_source.sink(otq.Passthrough())
@@ -263,6 +263,7 @@ def _get_integer_slice(self: 'Source', item: slice) -> Optional['Source']:
         raise ValueError("step value can't be negative or zero")
     if stop is not None and stop == 0:
         raise ValueError("stop value can't be zero")
+    # pylint: disable=chained-comparison
     if start and stop and start > 0 and stop > 0 and start >= stop:
         raise ValueError("stop value can't be less than start")
     if start and start < 0 and stop and stop > 0:
