@@ -201,14 +201,14 @@ def _fill_time_param_for_jwq(join_params, start_time, end_time, timezone):
 
 
 def _fill_aux_params_for_joins(
-    join_params, caching, end_time, prefix, start_time, symbol_name, timezone, join_with_collection=False
+    join_params, caching, end_time, prefix, start_time, symbol_name, timezone, for_join_with_collection=False
 ):
-    if symbol_name and not join_with_collection:
+    if symbol_name and not for_join_with_collection:
         join_params["symbol_name"] = symbol_name
     if prefix is not None:
         join_params["prefix_for_output_ticks"] = str(prefix)
     if caching:
-        if join_with_collection:
+        if for_join_with_collection:
             supported = ("per_symbol",)
         else:
             supported = ("cross_symbol", "per_symbol")
@@ -217,7 +217,7 @@ def _fill_aux_params_for_joins(
         else:
             raise ValueError(f"Unknown value for caching param, please use None or any of {supported}.")
     _fill_time_param_for_jwq(join_params, start_time, end_time, timezone)
-    if join_with_collection:
+    if for_join_with_collection:
         del join_params['timezone']
 
 
@@ -510,7 +510,7 @@ def join_with_collection(
     )
 
     _fill_aux_params_for_joins(
-        join_params, caching, end, prefix, start, symbol_name=None, timezone=None, join_with_collection=True
+        join_params, caching, end, prefix, start, symbol_name=None, timezone=None, for_join_with_collection=True
     )
     res.sink(otq.JoinWithCollectionSummary(**join_params))
     res._add_table()
@@ -909,7 +909,7 @@ def join_with_query(
         process_query_asynchronously=process_query_async,
     )
     if concurrency is not None:
-        if type(concurrency) is not int or concurrency <= 0:
+        if not isinstance(concurrency, int) or concurrency <= 0:
             raise ValueError('Wrong value of concurrency parameter passed! concurrency should be a positive integer')
         join_params['shared_thread_count'] = concurrency
 
