@@ -15,7 +15,7 @@ def _wrap_object(o):
 
 
 def _type_error_for_op(op, types):
-    raise TypeError(f"Unsupported operand type(s) for {op} operation: {types}")
+    return TypeError(f"Unsupported operand type(s) for {op} operation: {types}")
 
 
 def _init_binary_op(prev_op, other):
