@@ -880,6 +880,7 @@ class Operation:
                 self._op_str = op_str
                 self._dtype = dtype
             return op_str, dtype
+        return None
 
     def _convert_to(self, to_type):
         return _Operation(_methods.CONVERSIONS[self.dtype, to_type], [self])
@@ -889,16 +890,15 @@ class Operation:
         if dtype is bool:
             return self
         if are_ints_not_time(dtype):
-            self = _Operation(_methods.ne, (self, 0))
+            return _Operation(_methods.ne, (self, 0))
         elif are_time(dtype):
-            self = _Operation(_methods.ne, (self._convert_to(int), 0))
+            return _Operation(_methods.ne, (self._convert_to(int), 0))
         elif are_floats(dtype):
-            self = _Operation(_methods.ne, (self, 0.0))
+            return _Operation(_methods.ne, (self, 0.0))
         elif are_strings(dtype):
-            self = _Operation(_methods.ne, (self, ""))
+            return _Operation(_methods.ne, (self, ""))
         else:
             raise TypeError("Filter expression should return bool, int, float or string")
-        return self
 
     def _replace_parameters(self, operation_cb, return_replace_tuples=False):
         """
