@@ -362,9 +362,9 @@ class Source:
                 raise KeyError(f'Column name {name} is not in the schema. Please, check that this column '
                                'is in the schema or add it using the .schema property')
 
-            if name == 0 or name == 1:
+            if name in (0, 1):
                 raise ValueError(f"constant {name} are not supported for indexing for now, please use otp.Empty")
-            if type(name) in (int, float):
+            if isinstance(name, (int, float)):
                 raise ValueError("integer indexes are not supported")
             self.__dict__[name] = _Column(name, dtype, self)
         else:
@@ -775,6 +775,7 @@ class Source:
             )
 
             return mqt_ep
+        return None
 
     def _set_date_range_and_symbols(self, symbols=None, start=None, end=None):
         # will modify self
@@ -1208,7 +1209,7 @@ class Source:
         if not (
             issubclass(type(ep), otq.graph_components.EpBase)
             or issubclass(type(ep), otq.graph_components.EpBase.PinnedEp)
-            or type(ep) is tuple
+            or isinstance(ep, tuple)
         ):
             raise TypeError("sinking is allowed only for EpBase instances")
 
@@ -1217,7 +1218,7 @@ class Source:
         else:
             obj = self.copy()
 
-        if type(ep) is tuple:
+        if isinstance(ep, tuple):
             # for already existed EP fetched from _ProxyNode
             obj.__node.sink(out_pin, *ep)
         else:
@@ -1244,11 +1245,11 @@ class Source:
         if not (
             issubclass(type(ep), otq.graph_components.EpBase)
             or issubclass(type(ep), otq.graph_components.EpBase.PinnedEp)
-            or type(ep) is tuple
+            or isinstance(ep, tuple)
         ):
             raise TypeError("sourcing is allowed only for EpBase instances")
 
-        if type(ep) is tuple:
+        if isinstance(ep, tuple):
             # for already existed EP fetched from _ProxyNode
             return self.__node.source(in_pin, *ep)
         else:
@@ -1259,11 +1260,11 @@ class Source:
         if not (
             issubclass(type(ep), otq.graph_components.EpBase)
             or issubclass(type(ep), otq.graph_components.EpBase.PinnedEp)
-            or type(ep) is tuple
+            or isinstance(ep, tuple)
         ):
             raise TypeError("sourcing is allowed only for EpBase instances")
 
-        if type(ep) is tuple:
+        if isinstance(ep, tuple):
             # for already existed EP fetched from _ProxyNode
             return self.__node.source_by_key(to_key, *ep)
         else:
@@ -1590,6 +1591,7 @@ class Source:
         write,
         write_parquet,
         save_snapshot,
+        write_text,
     )
     from ._source.source_methods.renames import (  # type: ignore[misc]
         _add_prefix_and_suffix,
@@ -1632,6 +1634,7 @@ class Source:
     from ._source.source_methods.misc import (  # type: ignore[misc]
         pause,
         insert_tick,
+        insert_at_end,
         transpose,
         cache,
         pnl_realized,
