@@ -278,9 +278,8 @@ class DB:
             tz_gmt = gettz('GMT')
             for inx in range(len(result)):
                 start_date = result['START_DATE'][inx]
-                if start_date < 0:
-                    # On Windows datetime.fromtimestamp throws an OSError for negative values
-                    start_date = 0
+                # On Windows datetime.fromtimestamp throws an OSError for negative values
+                start_date = max(start_date, 0)
                 start = datetime.fromtimestamp(start_date / 1000, tz=tz_gmt)
                 start = start.replace(tzinfo=None)
                 try:
@@ -376,8 +375,7 @@ class DB:
             # future is not loaded yet
             if locator_start > today:
                 continue
-            if locator_end > today:
-                locator_end = today
+            locator_end = min(locator_end, today)
 
             if respect_acl:
                 try:
@@ -627,7 +625,7 @@ class DB:
                            context=self.context)
 
         result = get_schema(use_cache=True)
-        if not len(result):
+        if result.empty:
             # in case cache settings in database are bad (e.g. BEXRTS-1220)
             result = get_schema(use_cache=False)
 
@@ -719,8 +717,6 @@ class DB:
         >>> us_comp_db.symbols(date=otp.dt(2022, 3, 1), tick_type='TRD', pattern='^AAP.*')
         ['AAP', 'AAPL']
         """
-        import onetick.py as otp
-
         if date is None:
             date = self.last_date
         if timezone is None:
