@@ -10,7 +10,7 @@ class _MaxOperator(_Operation):
         super().__init__(dtype=get_type_by_objects(objs))
 
         def _str_max(l_val, r_val):
-            if type(r_val) is list:
+            if isinstance(r_val, list):
                 if len(r_val) > 1:
                     r_val = _str_max(r_val[0], r_val[1:])
                 else:
@@ -55,7 +55,7 @@ class _MinOperator(_Operation):
         super().__init__(dtype=get_type_by_objects(objs))
 
         def _str_min(l_val, r_val):
-            if type(r_val) is list:
+            if isinstance(r_val, list):
                 if len(r_val) > 1:
                     r_val = _str_min(r_val[0], r_val[1:])
                 else:
