@@ -494,7 +494,7 @@ def run(query: Union[Callable, Dict, otp.Source, otp.MultiOutputSource,  # NOSON
         query = otp.MultiOutputSource(query)
 
     params_saved_to_otq = {}
-    if isinstance(query, otp.Source) or isinstance(query, otp.MultiOutputSource):
+    if isinstance(query, (otp.Source, otp.MultiOutputSource)):
         start = None if start is utils.adaptive else start
         end = None if end is utils.adaptive else end
         params_saved_to_otq = dict(
@@ -660,9 +660,9 @@ def _form_dict_from_list(data_list, output_structure):
         d = defaultdict(list)
         for node, df in lst:
             d[node].append(df)
-        for node in d.keys():  # noqa
-            if len(d[node]) == 1:
-                d[node] = d[node][0]
+        for node, node_list in d.items():
+            if len(node_list) == 1:
+                d[node] = node_list[0]
         if len(d) == 1:
             d = list(d.values())[0]
         else:  # converting defaultdict to regular dict
@@ -671,7 +671,7 @@ def _form_dict_from_list(data_list, output_structure):
 
     def get_dataframe(data):
         if output_structure == 'df':
-            return pd.DataFrame({col_name: col_value for col_name, col_value in data})
+            return pd.DataFrame(dict(data))
         else:
             import polars
             if isinstance(data, polars.DataFrame):
@@ -749,7 +749,7 @@ def _process_empty_results(result, query_schema, output_structure):
         (field, np.array([], dtype=otp.types.type2np(dtype)))
         for field, dtype in {**query_schema, 'Time': otp.nsectime}.items()
     ]
-    if type(result) is otq.SymbolNumpyResultMap:
+    if isinstance(result, otq.SymbolNumpyResultMap):
         empty_data = dict(schema)
     else:
         empty_data = schema
@@ -758,7 +758,7 @@ def _process_empty_results(result, query_schema, output_structure):
         import polars
         empty_data = polars.DataFrame(dict(schema))
 
-    if type(result) is otq.SymbolNumpyResultMap:
+    if isinstance(result, otq.SymbolNumpyResultMap):
         for result_item in result.get_dict().values():
             for node_name, symbol_result in result_item.items():
                 if len(symbol_result[0]) == 0:
@@ -814,6 +814,7 @@ def _get_start_end(start, end, timezone):
 
     # `isinstance(obj, datetime.date)` is not correct because
     # isinstance(<datetime.datetime object>, datetime.date) = True
+    # pylint: disable=unidiomatic-typecheck
     if type(start) is datetime.date:
         start = datetime.datetime(start.year, start.month, start.day)
     if type(end) is datetime.date:
