@@ -16,7 +16,7 @@ from . import utils
 from . import license as _license
 from . import db as _db
 from . import servers as _servers
-from .configuration import config
+from . import configuration
 from .db._inspection import databases as _databases
 
 
@@ -320,6 +320,7 @@ class ACL(_FileHandler):
     def reload(self, db=None):
         if self._session_ref is not None:
             return utils.reload_config(db, config_type='ACCESS_LIST')
+        return None
 
     def _read_dbs(self):
         get_db = GetAll()
@@ -433,6 +434,7 @@ class Locator(_FileHandler):
     def reload(self, db_=None):
         if self._session_ref is not None:
             return utils.reload_config(db_, config_type='LOCATOR')
+        return None
 
     def _apply_actions(self, actions, print_writer=False):
         writer = PrintWriter() if print_writer else FileWriter(self.path)
@@ -1300,11 +1302,11 @@ class TestSession(Session):
         ``DEMO_L1`` is the database defined in the default locator generated by onetick.py
         and it is also a name of the database commonly used in the OneTick ecosystem, academy courses, etc.
         """
-        config['tz'] = 'EST5EDT'
-        config['default_db'] = 'DEMO_L1'
-        config['default_symbol'] = 'AAPL'
-        config['default_start_time'] = datetime(2003, 12, 1, 0, 0, 0)
-        config['default_end_time'] = datetime(2003, 12, 4, 0, 0, 0)
+        configuration.config['tz'] = 'EST5EDT'
+        configuration.config['default_db'] = 'DEMO_L1'
+        configuration.config['default_symbol'] = 'AAPL'
+        configuration.config['default_start_time'] = datetime(2003, 12, 1, 0, 0, 0)
+        configuration.config['default_end_time'] = datetime(2003, 12, 4, 0, 0, 0)
         super().__init__(*args, **kwargs)
 
 
