@@ -329,8 +329,7 @@ class DataSource(Source):
             start = None  # means that use the last date with data
 
         if isinstance(db, list):
-            ''' This case of a merge, since we need to get combined schema
-            across different tick types and dbs '''
+            # This case of a merge, since we need to get combined schema across different tick types and dbs
             for t_db in db:
                 if t_db.startswith('expr('):
                     continue
@@ -358,8 +357,8 @@ class DataSource(Source):
                 schema.update(db_schema)
 
         if db is None or isinstance(db, _SymbolParamColumn):
-            ''' In this case we can't get schema, because db is calculated dynamically.
-            Set to empty to indicate that in this case we expect the manually set schema. '''
+            # In this case we can't get schema, because db is calculated dynamically.
+            # Set to empty to indicate that in this case we expect the manually set schema.
             schema = {}
         return schema
 
@@ -430,22 +429,20 @@ class DataSource(Source):
 
     def __prepare_db_tick_type(self, db, tick_type, start, end):
         if isinstance(db, list):
-            ''' If everything is correct then this branch should leave
-            the `db` var as a list of databases with tick types and the
-            `tick_type` var is None.
-            Valid cases:
-                - Fully defined case. The `db` parameter has a list of databases where
-                  every database has a tick type, when the `tick_type`
-                  parameter has default value or None (for backward compatibility)
-                - Partially defined case. The `db` parameter has a list of databases but
-                  not every database has a tick type, and meantime the `tick_type`
-                  is passed to not None value. In that case databases without tick type
-                  are exetended with a tick type from the `tick_type` parameter
-                - No defined case. The `db` parameter has a list of databases and
-                  every database there has no tick type, and the `tick_type` is
-                  set to not None value. In that case every database is extended with
-                  the tick type from the `tick_type`.
-            '''
+            # If everything is correct then this branch should leave
+            # the `db` var as a list of databases with tick types and the `tick_type` var is None.
+            # Valid cases:
+            #     - Fully defined case. The `db` parameter has a list of databases where
+            #       every database has a tick type, when the `tick_type`
+            #       parameter has default value or None (for backward compatibility)
+            #     - Partially defined case. The `db` parameter has a list of databases but
+            #       not every database has a tick type, and meantime the `tick_type`
+            #       is passed to not None value. In that case databases without tick type
+            #       are exetended with a tick type from the `tick_type` parameter
+            #     - No defined case. The `db` parameter has a list of databases and
+            #       every database there has no tick type, and the `tick_type` is
+            #       set to not None value. In that case every database is extended with
+            #       the tick type from the `tick_type`.
 
             def db_converter(_db):
                 if isinstance(_db, DB):
@@ -483,8 +480,8 @@ class DataSource(Source):
             db = db.name  # ... and we go to the next branch
 
         if isinstance(db, str):
-            ''' The resulting `db` var contains a list with string value, that has the `db`
-            concatenated with the `tick_type`. '''
+            # The resulting `db` var contains a list with string value, that has the `db`
+            # concatenated with the `tick_type`.
             if '::' in db:
                 if tick_type is utils.adaptive or tick_type is None:
                     tick_type = db.split(':')[-1]
@@ -549,9 +546,8 @@ class DataSource(Source):
             tick_type = None
 
         if isinstance(db, _SymbolParamColumn):
-            ''' Do nothing, because we don't know whether db will come with the tick
-            type or not. The only one thing that definetely we know that tick_type
-            can not be utils.adpative '''
+            # Do nothing, because we don't know whether db will come with the tick type or not.
+            # The only one thing that definetely we know that tick_type can not be utils.adaptive
             if tick_type is utils.adaptive:
                 # TODO: need to test this case
                 raise ValueError('The `db` is set to the symbol param, in that case '
@@ -559,8 +555,7 @@ class DataSource(Source):
                                  'or to None')
 
         if db is None:
-            ''' This case means that database comes with the symbol name, then tick type
-            should be defined '''
+            # This case means that database comes with the symbol name, then tick type should be defined
             if tick_type is utils.adaptive or tick_type is None:
                 raise ValueError('The `db` is not specified that means database is '
                                  'expected to be defined with the symbol name. '
@@ -889,14 +884,9 @@ class DataSource(Source):
         )
 
         if (
-            isinstance(symbol, Source)
+            isinstance(symbol, (Source, query, _QueryEvalWrapper, otq.GraphQuery))
             or hasattr(symbol, "__iter__")
-            and not isinstance(symbol, dict)
-            and not isinstance(symbol, str)
-            and not isinstance(symbol, (OnetickParameter, _SymbolParamColumn))
-            or isinstance(symbol, query)
-            or isinstance(symbol, _QueryEvalWrapper)
-            or isinstance(symbol, otq.GraphQuery)
+            and not isinstance(symbol, (dict, str, OnetickParameter, _SymbolParamColumn))
         ):
             super().__init__(
                 _start=start,
@@ -965,7 +955,7 @@ class DataSource(Source):
         if where_clause_for_back_ticks is not None:
             params['where_clause_for_back_ticks'] = where_clause_for_back_ticks
 
-        if isinstance(db, list) or isinstance(db, _SymbolParamColumn):
+        if isinstance(db, (list, _SymbolParamColumn)):
             src = self._create_source(otq.Passthrough(**params),
                                       back_to_first_tick=back_to_first_tick,
                                       keep_first_tick_timestamp=keep_first_tick_timestamp)
