@@ -70,9 +70,9 @@ class Query(Source):
             schema=schema, **kwargs,
         )
 
-    def base_ep(self, query, out_pin):
-        nested = otq.NestedOtq(query.path, query.str_params)
-        graph = query.graph_info
+    def base_ep(self, query_object, out_pin):
+        nested = otq.NestedOtq(query_object.path, query_object.str_params)
+        graph = query_object.graph_info
 
         if out_pin is utils.adaptive:
             if graph is not None:
@@ -80,7 +80,7 @@ class Query(Source):
                     return Source(nested[graph.nested_outputs[0].NESTED_OUTPUT])
                 if len(graph.nested_outputs) > 1:
                     raise ValueError(
-                        f'Query "{query.query_name}" has multiple outputs, but you have not '
+                        f'Query "{query_object.query_name}" has multiple outputs, but you have not '
                         "specified which one should be used. You could specify it"
                         ' using "out_pin" parameter of the Query constructor.'
                     )
@@ -91,7 +91,7 @@ class Query(Source):
             existed_out_pins = set(map(operator.attrgetter("NESTED_OUTPUT"), graph.nested_outputs))
             if out_pin not in existed_out_pins:
                 raise ValueError(
-                    f'Query "{query.query_name}" does not have the "{out_pin}" output, there are only following '
+                    f'Query "{query_object.query_name}" does not have the "{out_pin}" output, there are only following '
                     f"output pins exist: {','.join(existed_out_pins)}"
                 )
         return Source(nested[out_pin])
@@ -369,7 +369,7 @@ class query:
         def __getitem__(self, key):
             output_pins = []
 
-            if type(key) is tuple:
+            if isinstance(key, tuple):
                 output_pins = list(key)
             elif isinstance(key, str):
                 output_pins = [key]
@@ -459,7 +459,7 @@ class query:
                 open_char = None
                 continue
 
-            if not open_char and (c == "'" or c == '"'):
+            if not open_char and c in ("'", '"'):
                 open_char = c
                 last_inx = inx + 1
                 continue
