@@ -817,9 +817,9 @@ def TTicks(data):  # NOSONAR
                   "You could use the `Ticks` to pass data in the same format there",
                   FutureWarning)
 
-    dt = {}
+    data_dict = {}
 
     for inx, key in enumerate(data[0]):
-        dt[key] = [sub_list[inx] for sub_list in data[1:]]
+        data_dict[key] = [sub_list[inx] for sub_list in data[1:]]
 
-    return Ticks(dt)
+    return Ticks(data_dict)
