@@ -15,7 +15,7 @@ from onetick.py.core import query_inspector
 from . import adaptive
 
 
-if otp.__webapi__ or os.getenv("OTP_SKIP_OTQ_VALIDATION", False):
+if otp.__webapi__ or os.getenv("OTP_SKIP_OTQ_VALIDATION"):
     MEASURE_PERF = None
 else:
     # see http://solutions.pages.soltest.onetick.com/iac/onetick-server/MeasurePerf.html
@@ -294,8 +294,7 @@ class PerformanceSummary:
         """
         Iterate over list of summary :attr:`entries`.
         """
-        for entry in self.entries:
-            yield entry
+        yield from self.entries
 
 
 class OrdinarySummary(PerformanceSummary):
