@@ -26,8 +26,8 @@ def default_clean_up(clean_up):
 
 
 def get_logger(*args):
-    from ..log import get_logger
-    return get_logger(__name__, *args)
+    from .. import log
+    return log.get_logger(__name__, *args)
 
 
 class CleanUpFinalizer:
